Myosin
======
.. image:: https://img.shields.io/pypi/v/myosin?color=blue
    :target: https://pypi.org/project/myosin/
    :alt: PyPi Version

.. image:: https://github.com/ztnel/myosin/actions/workflows/ci.yaml/badge.svg
    :target: https://github.com/ztnel/myosin/actions/workflows/ci.yaml
    :alt: Continuous Integration Status

.. image:: https://codecov.io/gh/ztnel/myosin/branch/master/graph/badge.svg?token=G2DNQAGVIP
    :target: https://codecov.io/gh/ztnel/myosin
    :alt: Code Coverage Summary

.. image:: https://readthedocs.org/projects/myosin/badge/?version=latest
    :target: https://myosin.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://img.shields.io/pypi/l/myosin
    :target: https://pypi.org/project/myosin/ 
    :alt: PyPI - License

About
-----
*Myosin* is an experimental framework for developing lightweight state-driven software systems. *Myosin* provides a flexible and homogenous strictly-typed API for facilitating data transactions between system modules simplifying developement and improving system scalability.

Installation
------------

*Myosin* is distributed on PyPI_ and can be installed using ``pip``:

.. code-block:: console

   $ pip install myosin

.. _PyPI: https://pypi.python.org/pypi/sphinx_rtd_theme

Core Features
~~~~~~~~~~~~~
#. Built on Python Standard Libraries
#. Thread-safe Accessors
#. Strictly Typed Object-Oriented API
#. Built-in Fault-Tolerance
#. State-driven Asynchrounous Callbacks
#. `Prometheus <https://prometheus.io>`_ Monitoring

Visit the `documentation page <https://myosin.readthedocs.io>`_ to learn more.

Contributing
------------
Contributions are welcome! Please see the `issue backlog <https://github.com/ztnel/myosin/issues>`_ and `project kanban <https://github.com/ztnel/myosin/projects/1>`_ for active work items or contact me at `christian@leapsystems.online <mailto:christian@leapsystems.online>`_.

License
-------
This project is licensed under the terms of the `MIT License <LICENSE>`_
